package rvl.swv;
import rvl.swv.*;
import java.io.*;

/**
  Engine for R code.  Present version suppresses all echoing of
  code, and all output produced by a code chunk comes at the end.
  This is not <TT>Sweave</TT>'s behavior.
 */
public class REngine extends AbstractEngine {

    public REngine() {
        engineName = "REngine";
        codeExt = ".R";
        outExt = ".Rout";
        commentStart = "# ";
        commentEnd = "";
        okfigfmts = new int[] {FigFile.PDF, FigFile.PS, FigFile.PNG, FigFile.JPG};
        startupCode = "options(echo=FALSE)";
    }


    public void putSeparator(String text) {
        putCode("cat(\"" + text + "\\n\")");
    }

// Have to use cat so we don't get obs number
    public void putExpr(String expr) {
        putCode("cat(paste(" + expr + ", \"\\n\"))");
    }

    public FigFile setupFig(String chunkName) {
        FigFile fig = super.setupFig(chunkName);
        if (fig != null) {
            int fmt = fig.getFormat();
            String cmd = FigFile.labels[fmt], extargs = "";
            double wid = fig.getWidth(), ht = fig.getHeight();
            if (fmt == FigFile.JPG)
                cmd = "jpeg";
            if (fmt == FigFile.PNG || fmt == FigFile.JPG) {
                wid *= 72; ht *= 72;
                extargs = ", res=72";
            }
            else if (fmt == FigFile.PS) {
                cmd = "postscript";
                extargs = ", horizontal = FALSE";
            }
            cmd = cmd + "(\"" + fig.getFileName() + "\", width=" + wid
                + ", height=" + ht + extargs + ")";
            putCode(cmd);
        }
        return fig;
    }

    public void closeFig() {
        putCode("dev.off()");
    }



} // ----- END OF REngine -------

